# Please keep this package in sync with FC

%global major   4
%define libname %mklibname capstone %major
%define devname %mklibname capstone -d

# don't provide libcapstone.so.3 with py2/3 pkgs
%global __provides_exclude_from %{?__provides_exclude_from:%__provides_exclude_from|}%{python3_sitelib}/.*\.so
%global __provides_exclude_from %{?__provides_exclude_from:%__provides_exclude_from|}%{python2_sitelib}/.*\.so

Name:           capstone
Version:        4.0.2
Release:        %mkrel 1
Summary:        A lightweight multi-platform, multi-architecture disassembly framework
Group:          System/Libraries

%global         gituser         aquynh
%global         gitname         capstone
# 4.0.1 release
%global         commit          f9c6a90489be7b3637ff1c7298e45efafe7cf1b9
# 
#global         commit          75c05281b4bc8e8c41a1ab7f91705401caa3832a
%global         shortcommit     %(c=%{commit}; echo ${c:0:7})

License:        BSD
URL:            http://www.capstone-engine.org/
#               https://github.com/aquynh/capstone/releases
#Source0:        https://github.com/%{gituser}/%{gitname}/archive/%{commit}/%{name}-%{version}-%{shortcommit}.tar.gz
Source0:        https://github.com/%{gituser}/%{gitname}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz

# Test suite binary samples to be used for disassembly
# Source1:        

# Fedora 29 makes python executable separate from python2 and python3. This patch makes
# it possible to specify PYTHON2 and PYTHON3 binary to be explicit that by "python" we mean "python2"
# Patch0:         capstone-python.patch


%global with_python3 1

%global srcname distribute

BuildRequires:  git
BuildRequires:  jna
BuildRequires:  java-devel
%if 0%{?with_python3}
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
%endif # if with_python3
%global _hardened_build 1


%description
Capstone is a disassembly framework with the target of becoming the ultimate
disasm engine for binary analysis and reversing in the security community.

%package        -n %libname
Summary:        A lightweight multi-platform, multi-architecture disassembly framework
Group:          System/Libraries
Obsoletes:      %{_lib}capstone0 < 3.0.4-3

%description    -n %libname
Capstone is a disassembly framework with the target of becoming the ultimate
disasm engine for binary analysis and reversing in the security community.

%package        -n %devname
Summary:        Development files for %{name}
Group:		Development/Other
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Provides:	capstone-devel = %{version}-%{release}

%description    -n %devname
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%if 0%{?with_python3}
%package	-n python3-capstone
Summary:	Python3 bindings for %{name}
Group:		Development/Python
Requires:	%{libname}%{?_isa} = %{version}-%{release}

%description	-n python3-capstone
The python3-%{name} package contains python3 bindings for %{name}.
%endif # with_python3

%package        java
Summary:        Java bindings for %{name}
Group:          Development/Java
Requires:       %{name} >= %{version}-%{release}
BuildArch:      noarch

%description    java
The %{name}-java package contains java bindings for %{name}.

%prep
# autosetup -n %{gitname}-%{commit} -S git
%autosetup -n %{gitname}-%{version} -S git

%build
DESTDIR="%{buildroot}" 	V=1 CFLAGS="%{optflags}" \
LIBDIRARCH="%{_lib}" INCDIR="%{_includedir}" \
make PYTHON3=%{__python3} %{?_smp_mflags}

# Fix pkgconfig file
sed -i 's;%{buildroot};;' capstone.pc
grep -v archive capstone.pc > capstone.pc.tmp
mv capstone.pc.tmp capstone.pc

# build python bindings
pushd bindings/python
%if 0%{?with_python3}
%py3_build
%endif # with_python3
popd

# build java bindings
pushd bindings/java
make PYTHON3=%{__python3} CFLAGS="%{optflags}" # %{?_smp_mflags} parallel seems broken
popd

%install
DESTDIR=%{buildroot} LIBDIRARCH=%{_lib} \
INCDIR="%{_includedir}" make install
find %{buildroot} -name '*.la' -exec rm -f {} ';'
find %{buildroot} -name '*.a' -exec rm -f {} ';'

# install python bindings
pushd bindings/python
%if 0%{?with_python3}
%py3_install
%endif # with_python3
popd

# install java bindings
install -D -p -m 0644 bindings/java/%{name}.jar  %{buildroot}/%{_javadir}/%{name}.jar

#%check
#ln -sf libcapstone.so libcapstone.so.%{major}
#make check LD_LIBRARY_PATH="`pwd`"


%files
%{_bindir}/cstool

%files -n %libname
%license LICENSE.TXT LICENSE_LLVM.TXT
%doc CREDITS.TXT ChangeLog README.md SPONSORS.TXT
%{_libdir}/*.so.%{major}{,.*}

%files -n %devname
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*

%if 0%{?with_python3}
%files -n python3-capstone
%{python3_sitelib}/*egg-info
%{python3_sitelib}/%{name}
%endif # _with_python3

%files java
%{_javadir}/



%changelog
* Mon May 11 2020 tv <tv> 4.0.2-1.mga8
+ Revision: 1582891
- 4.0.2

* Sun Feb 16 2020 umeabot <umeabot> 4.0.1-4.mga8
+ Revision: 1532197
- Mageia 8 Mass Rebuild

* Mon Sep 16 2019 tv <tv> 4.0.1-3.mga8
+ Revision: 1442077
- rebuild for python-3.8
- drop python2 subpkg
- rebuild for rpm-4.15

* Sat Jan 12 2019 tv <tv> 4.0.1-1.mga7
+ Revision: 1355753
- new release
- major is now 4

* Tue Jan 08 2019 shlomif <shlomif> 3.0.5-4.mga7
+ Revision: 1351561
- Rebuild for python3 3.7

* Tue Sep 11 2018 wally <wally> 3.0.5-3.mga7
+ Revision: 1258446
- don't provide libcapstone.so.3 with python pkgs

* Thu Aug 30 2018 daviddavid <daviddavid> 3.0.5-2.mga7
+ Revision: 1255695
- fix dependencies

* Tue Aug 28 2018 tv <tv> 3.0.5-1.mga7
+ Revision: 1255270
- 3.0.5

* Sat Feb 10 2018 daviddavid <daviddavid> 3.0.4-3.mga7
+ Revision: 1200017
- fix requires
- libmajor is 3
- use new python macros

* Mon Nov 27 2017 tv <tv> 3.0.4-2.mga7
+ Revision: 1179996
- add missing provides
- imported package capstone

